<?php

/**
 * Class Easy_Translate_Projects.
 *
 * @package    Easy_Translate
 * @subpackage Easy_Translate/admin
 */
class Easy_Translate_Projects
{
    /**
     * The project list.
     *
     * @var array
     */
    public $project_list = array();

    /**
     * Pagination links.
     *
     * @var array
     */
    protected $project_meta = array();

    /**
     * Easy_Translate_Projects constructor.
     */
    public function __construct()
    {

        $this->project_meta = array('last_page' => 0);

    }

    /**
     * Process actions triggered by the user
     */
    public function handle_actions()
    {
        $options = get_option(EASY_TRANSLATE_INTEGRATION_OPTION);
        $service = new Easy_Translate_API_Laas(Easy_Translate_API_Integration::map_fields($options));

        if (isset($_REQUEST['action'], $_REQUEST['project_id']) && $_REQUEST['action'] === 'accept') {
            $response = $service->accept_project($_REQUEST['project_id']);
            if (isset($response['error'])) {
                add_settings_error(
                    '',
                    'accept-project-error',
                    $response['error'] ?? '',
                    'error'
                );
            } else {
                add_settings_error(
                    '',
                    'accept-project-success',
                    __('Accepted successfully!', EASY_TRANSLATE),
                    'success'
                );
            }
        } elseif (isset($_REQUEST['action'], $_REQUEST['project_id']) && $_REQUEST['action'] === 'decline') {
            $response = $service->decline_project($_REQUEST['project_id']);
            if (isset($response['error'])) {
                add_settings_error(
                    '',
                    'decline-project-error',
                    $response['error'] ?? '',
                    'error'
                );
            } else {
                add_settings_error(
                    '',
                    'decline-project-success',
                    __('Declined successfully!', EASY_TRANSLATE),
                    'success'
                );
            }
        }
    }

    /**
     * Render the project list.
     */
    public function render()
    {
        $this->handle_actions();
        $this->project_list = $this->get_projects();
        include_once(EASY_TRANSLATE_ROOT . 'admin/partials/projects.php');

    }

    /**
     * Returns the projects.
     *
     * @return mixed
     */
    protected function get_projects()
    {

        $options = get_option(EASY_TRANSLATE_INTEGRATION_OPTION);
        $service = new Easy_Translate_API_Laas(Easy_Translate_API_Integration::map_fields($options));
        $params = isset($_GET['paged']) ? '?page=' . $_GET['paged'] : '';
        $response = $service->fetch_all_projects($params);

        if (isset($response['error'])) {
            add_settings_error(
                '',
                'project-error',
                $response['error'] ?? '',
                'error'
            );
            add_settings_error(
                '',
                'project-hint',
                $response['hint'] ?? '',
                'info'
            );

            return array();
        }

        $this->project_meta = ($response['meta']);

        return $response['data'];

    }

}
