<?php

/**
 * Class Easy_Translate_Translation.
 *
 * @package    Easy_Translate
 * @subpackage Easy_Translate/admin
 */
class Easy_Translate_Translation
{

    /**
     * Translation status.
     */
    const STATUS_COMPLETE = 10;

    /**
     * The completed task action callback.
     */
    public function completed_task_callback()
    {
        $json = json_decode(file_get_contents("php://input"), true);

        if ($json['event'] === 'task.updated') {
            $task = $json['data'];
            $target_language = get_wpml_target_language_code($task['attributes']['target_language']);
            $content = $this->fetch_content($task);

            foreach ($content as $item) {
                $handler = key($item) . '_handler';
                $this->$handler(current($item), $target_language);
            }
        }

        wp_die();

    }

    /**
     * Adds post string translation.
     *
     * @param $content
     * @param $target_language
     */
    protected function post_strings_handler($content, $target_language)
    {

        if (isset(current($content)['title']) && current($content)['title']) {
            if ($source_translations = Easy_Translate_Post_Translation_List::get_translations_by_element_id(key($content))) {
                if ($translations = Easy_Translate_Post_Translation_List::get_translations_by_source($source_translations,
                    $target_language)) {
                    Easy_Translate_Post_Translation_List::update_post_title($translations['element_id'],
                        current($content)['title']);
                }
            }
        }
        $this->strings_handler(current($content)['content'], $target_language);

    }

    /**
     * Adds post translation.
     *
     * @param $content
     * @param $target_language
     */
    protected function post_full_handler($content, $target_language)
    {

        $source_post_id = key($content);
        $post_title = current($content)['title'] ?? '';
        $post_content = current($content)['content'];

        if ($source_translations = Easy_Translate_Post_Translation_List::get_translations_by_element_id($source_post_id)) {

            if ($translations = Easy_Translate_Post_Translation_List::get_translations_by_source($source_translations,
                $target_language)) {

                if (isset($translations['element_id'])) {
                    Easy_Translate_Post_Translation_List::update_post($translations['element_id'], $post_content,
                        $post_title);
                    Easy_Translate_Post_Translation_List::update_translations_status($translations['translation_id'],
                        self::STATUS_COMPLETE);
                }
            }
        }

    }

    /**
     * Adds string translation.
     *
     * @param $content
     * @param $target_language
     */
    protected function strings_handler($content, $target_language)
    {
        global $wpdb;

        foreach ($content as $id => $value) {
            $string = new WPML_ST_String($id, $wpdb);
            $string->set_translation($target_language, $value, self::STATUS_COMPLETE);
        }
    }

    /**
     * Returns translated content.
     *
     * @param array $task
     * @return array
     */
    protected function fetch_content($task)
    {

        $options = get_option(EASY_TRANSLATE_INTEGRATION_OPTION);
        $service = new Easy_Translate_API_Laas(Easy_Translate_API_Integration::map_fields($options));

        return $service->get_target_content($task['attributes']['target_content']);

    }

    /**
     * Returns admin user id.
     *
     * @return mixed
     */
    public function get_admin_user_id()
    {

        global $wpdb;
        $query = "SELECT user_id from {$wpdb->prefix}usermeta WHERE meta_key='wp_user_level' AND meta_value=10 LIMIT 1;";

        return $wpdb->get_row($query, ARRAY_A)['user_id'];

    }

}
