<?php

/**
 * Returns source languages.
 *
 * @return array
 */
function get_source_language_array()
{
    return [
        'sq'      => 'sq',
        'ar'      => 'ar',
        'hy'      => 'hy',
        'eu'      => 'eu',
        'bn'      => 'bn',
        'bs'      => 'bs',
        'bg'      => 'bg',
        'ca'      => 'ca',
        'zh-hans' => 'zh_CN',
        'zh-hant' => 'zh_HK',
        'hr'      => 'hr',
        'cs'      => 'cs',
        'da'      => 'da',
        'nl'      => 'nl_NL',
        'en'      => 'en',
        'eo'      => 'eo',
        'et'      => 'et',
        'fi'      => 'fi',
        'fr'      => 'fr',
        'gl'      => 'gl',
        'de'      => 'de',
        'el'      => 'el',
        'he'      => 'he',
        'hi'      => 'hi',
        'hu'      => 'hu',
        'is'      => 'is',
        'id'      => 'id',
        'ga'      => '',
        'it'      => 'it',
        'ja'      => 'ja',
        'ko'      => 'ko',
        'ku'      => '',
        'lv'      => 'lv',
        'lt'      => 'lt',
        'mk'      => 'mk',
        'ms'      => 'ms',
        'mt'      => 'mt',
        'mn'      => 'mn_MN',
        'ne'      => 'ne_NP',
        'no'      => 'nb',
        'fa'      => 'fa_IR',
        'pl'      => 'pl',
        'pt-br'   => '',
        'pt-pt'   => 'pt',
        'pa'      => 'pa',
        'qu'      => '',
        'ro'      => 'ro',
        'ru'      => 'ru',
        'sr'      => 'sr',
        'sk'      => 'sk',
        'sl'      => 'sl',
        'so'      => 'so',
        'es'      => 'es',
        'sv'      => 'sv',
        'ta'      => 'ta',
        'th'      => 'th',
        'tr'      => 'tr',
        'uk'      => 'uk',
        'ur'      => 'ur',
        'uz'      => 'uz',
        'vi'      => 'vi',
        'cy'      => 'cy',
        'yi'      => 'ji',
        'zu'      => 'zu',
    ];

}

/**
 * Returns target languages.
 *
 * @return array
 */
function get_target_language_array()
{
    return [
        'sq'      => 'sq',
        'ar'      => 'ar',
        'hy'      => 'hy',
        'eu'      => 'eu',
        'bn'      => 'bn',
        'bs'      => 'bs',
        'bg'      => 'bg',
        'ca'      => 'ca',
        'zh-hans' => 'zh_CN',
        'zh-hant' => 'zh_HK',
        'hr'      => 'hr',
        'cs'      => 'cs',
        'da'      => 'da',
        'nl'      => 'nl_NL',
        'en'      => 'en_GB',
        'eo'      => 'eo',
        'et'      => 'et',
        'fi'      => 'fi',
        'fr'      => 'fr_FR',
        'gl'      => 'gl',
        'de'      => 'de',
        'el'      => 'el',
        'he'      => 'he',
        'hi'      => 'hi',
        'hu'      => 'hu',
        'is'      => 'is',
        'id'      => 'id',
        'ga'      => '',
        'it'      => 'it_IT',
        'ja'      => 'ja',
        'ko'      => 'ko',
        'ku'      => '',
        'lv'      => 'lv',
        'lt'      => 'lt',
        'mk'      => 'mk',
        'ms'      => 'ms',
        'mt'      => 'mt',
        'mn'      => 'mn_MN',
        'ne'      => 'ne_NP',
        'no'      => 'nb',
        'fa'      => 'fa_IR',
        'pl'      => 'pl',
        'pt-br'   => 'pt_BR',
        'pt-pt'   => 'pt_PT',
        'pa'      => 'pa',
        'qu'      => '',
        'ro'      => 'ro_RO',
        'ru'      => 'ru',
        'sr'      => 'sr',
        'sk'      => 'sk',
        'sl'      => 'sl',
        'so'      => 'so',
        'es'      => 'es_ES',
        'sv'      => 'sv',
        'ta'      => 'ta',
        'th'      => 'th',
        'tr'      => 'tr',
        'uk'      => 'uk',
        'ur'      => 'ur',
        'uz'      => 'uz',
        'vi'      => 'vi',
        'cy'      => 'cy',
        'yi'      => 'ji',
        'zu'      => 'zu',
    ];

}

/**
 * Returns EasyTranslate source language code.
 *
 * @param $wpml_code
 * @return string
 */
function get_et_source_language_code($wpml_code)
{
    $langs = get_source_language_array();

    return $langs[$wpml_code] ?? '';
}

/**
 * Returns EasyTranslate target language code.
 *
 * @param $wpml_code
 * @return string
 */
function get_et_target_language_code($wpml_code)
{
    $langs = get_target_language_array();

    return $langs[$wpml_code] ?? '';
}

/**
 * Returns WPML source language code.
 *
 * @param $etLanguageCode
 * @return false|string
 */
function get_wpml_source_language_code($etLanguageCode)
{
    return array_search($etLanguageCode, get_source_language_array());
}

/**
 * Returns WPML target language code.
 *
 * @param $etLanguageCode
 * @return false|string
 */
function get_wpml_target_language_code($etLanguageCode)
{
    return array_search($etLanguageCode, get_target_language_array());
}

/**
 * Verifies that a correct security nonce was used with time limit.
 *
 * @param     $nonce
 * @param int $action
 * @return bool|int
 */
function wp_verify_nonce($nonce, $action = -1)
{

    if ($action === 'icl_st_save_translation_nonce') {
        return 1;
    }

    $nonce = (string)$nonce;
    $user = wp_get_current_user();
    $uid = (int)$user->ID;
    if (!$uid) {
        /**
         * Filters whether the user who generated the nonce is logged out.
         *
         * @param int    $uid    ID of the nonce-owning user.
         * @param string $action The nonce action.
         * @since 3.5.0
         */
        $uid = apply_filters('nonce_user_logged_out', $uid, $action);
    }

    if (empty($nonce)) {
        return false;
    }

    $token = wp_get_session_token();
    $i = wp_nonce_tick();

    // Nonce generated 0-12 hours ago.
    $expected = substr(wp_hash($i . '|' . $action . '|' . $uid . '|' . $token, 'nonce'), -12, 10);
    if (hash_equals($expected, $nonce)) {
        return 1;
    }

    // Nonce generated 12-24 hours ago.
    $expected = substr(wp_hash(($i - 1) . '|' . $action . '|' . $uid . '|' . $token, 'nonce'), -12, 10);
    if (hash_equals($expected, $nonce)) {
        return 2;
    }

    /**
     * Fires when nonce verification fails.
     *
     * @param string     $nonce  The invalid nonce.
     * @param string|int $action The nonce action.
     * @param WP_User    $user   The current user object.
     * @param string     $token  The user's session token.
     * @since 4.4.0
     */
    do_action('wp_verify_nonce_failed', $nonce, $action, $user, $token);

    // Invalid nonce.
    return false;

}
